powered by
stat_fan
Extracts the limits of the Ntiles of a distribution for use in the stat_fan function
do_fan(x, step = 0.01)
a data.frame containing
ymin : the lower limit of the quantile
ymax : the upper limit of the quantile
id : an identifier for the quantile
percent : the fill color to use in geom_fan
geom_fan
the value to summarize
the number of bins to break the data into, based on the quantile function
quantile
FanEuStockMarkets <- lapply(colnames(EuStockMarkets),function(id) { res <- do_fan(EuStockMarkets[,id]) res$id <- id return(res) }) FanEuStockMarkets <- do.call(rbind,FanEuStockMarkets)
Run the code above in your browser using DataLab